Update doc impact to only make bugs on merge

Throughout the Havana release, the use of doc impact in commit
messages has created many helpful bugs for the documentation team.

However, the initial plan where the flags inclusion would alert doc
team to take a look at patches while under review has not ocurred,
due to a lack of people. In addition, abandoned patches have been
a distraction.

As such, the docs team wishes to change the behaviour of doc impact
so that is creates bugs once patches have been merged. This patch
simply changes the logic to realise this.

Change-Id: I29bab0095719212f6c5e2b9c6b704ed328976b2b
diff --git a/jeepyb/cmd/notify_impact.py b/jeepyb/cmd/notify_impact.py
index 93f2e10..0f81b1c 100644
--- a/jeepyb/cmd/notify_impact.py
+++ b/jeepyb/cmd/notify_impact.py
@@ -79,11 +79,13 @@
 def process_impact(git_log, args):
     """Process DocImpact flag.
 
     If the 'DocImpact' flag is present, create a new documentation bug in
     the openstack-manuals launchpad project based on the git_log.
-    For non-documentation impacts notify the mailing list of impact.
+    For non-documentation impacts at all states of merge
+    notify the mailing list of impact.
     """
-    if args.impact.lower() == 'docimpact':
+    if args.impact.lower() == 'docimpact' and args.hook == "change-merged":
         create_bug(git_log, args, 'openstack-manuals')
         return
@@ -79,11 +79,13 @@
     """Process DocImpact flag.
 
-    If the 'DocImpact' flag is present, create a new documentation bug in
+    If the 'DocImpact' flag is present for a change that is merged,
+    create a new documentation bug in
     the openstack-manuals launchpad project based on the git_log.